package hu.elte.math;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

// vagy csak roviden: import java.io.*;

public class Matrix {

    private final int[][] elements;
    private final int height;
    private final int width;

    public Matrix(int height, int width) {
        this.elements = new int[height][width];
        this.width = width;
        this.height = height;
    }

    public static Matrix fromFile(String path) {
        BufferedReader br = null;
        Matrix result = null;
        try {
            br = new BufferedReader(new FileReader(path));

            String firstLine = br.readLine();
            String[] dimensions = firstLine.split("x");
            int height = Integer.parseInt(dimensions[0]);
            int width = Integer.parseInt(dimensions[1]);

            result = new Matrix(height, width);
            int rowCounter = 0;
            String line = null;
            while ((line = br.readLine()) != null) {
                String[] numbersInSameRow = line.split(" ");
                for (int columnCounter = 0; columnCounter < width; columnCounter++) {
                    int element = Integer.parseInt(numbersInSameRow[columnCounter]);
                    result.setElement(element, rowCounter, columnCounter);
                }
                rowCounter++;
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (br != null) {
                try {
                    br.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return result;
    }

    public int getElement(int row, int column) {
        return elements[row][column];
    }

    public void setElement(int element, int row, int column) {
        elements[row][column] = element;
    }

    public int getWidth() {
        return width;
    }

    public int getHeight() {
        return height;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < height; i++) {
            for (int j = 0; j < width; j++) {
                sb.append(elements[i][j]);
                if (j < width - 1) {
                    sb.append(' ');
                }
            }
            if (i < height - 1) {
                sb.append(" | ");
            }
        }
        return sb.toString();
    }

}